@@ -120,7 +120,7 @@ int Preferences::Config_Load()
     int Retour=1;
 
     //Base folder
-    BaseFolder.From_Local(Application->ExeName.c_str());
+    BaseFolder=Application->ExeName.c_str();
     BaseFolder=BaseFolder.substr(0, BaseFolder.rfind(_T("\\"))+1);
     if (!Dir::Exists(BaseFolder+_T("Plugin")))
         Dir::Create(BaseFolder+_T("Plugin"));
@@ -438,6 +438,7 @@ int Preferences::ExplorerShell()
         ".asf;ASFFile\r\n"
         ".avi;AVIFile\r\n"
         ".bdmv;BDMVFile\r\n"
+        ".bmp;BMPFile\r\n"
         ".clpi;CLPIFile\r\n"
         ".divx;AVIFile\r\n"
         ".dpg;DPGFile\r\n"
@@ -451,12 +452,16 @@ int Preferences::ExplorerShell()
         ".flac;FLACFile\r\n"
         ".flv;FlashVideoFile\r\n"
         ".gvi;AVIFile\r\n"
+        ".gif;GIFFile\r\n"
         ".h264;H264File\r\n"
+        ".hdmov;MOVFile\r\n"
         ".ifo;IfoFile\r\n"
         ".isma;ISMAFile\r\n"
         ".ismv;ISMVFile\r\n"
-        ".j2k;EAC3File\r\n"
-        ".jp2;EAC3File\r\n"
+        ".j2k;JPEGFile\r\n"
+        ".jp2;JPEGFile\r\n"
+        ".jpeg;JPEGFile\r\n"
+        ".jpg;JPEGFile\r\n"
         ".m1s;mpegFile\r\n"
         ".m1t;mpegFile\r\n"
         ".m1v;mpegFile\r\n"
@@ -492,12 +497,14 @@ int Preferences::ExplorerShell()
         ".ogg;OGGFile\r\n"
         ".ogm;OGMFile\r\n"
         ".ogv;OGVFile\r\n"
+        ".png;PNGFile\r\n"
         ".qcp;QCPFile\r\n"
         ".qt;QTFile\r\n"
         ".ra;RMFile\r\n"
         ".rm;RMFile\r\n"
         ".rmvb;FlashVideoFile\r\n"
         ".smv;SMVFile\r\n"
+        ".stl;STLFile\r\n"
         ".swf;FlashFile\r\n"
         ".tp;FlashVideoFile\r\n"
         ".trp;TRPFile\r\n"
@@ -532,6 +539,7 @@ int Preferences::ExplorerShell()
                 Reg->CloseKey();
 
                 //Test if old Media Info shell extension is known
+                /*
                 if (Player!="" && Reg->OpenKey(Player+_T("\\Shell\\Media Info\\Command"), false))
                 {
                     //Should not be here, deleting
@@ -540,6 +548,7 @@ int Preferences::ExplorerShell()
                     IsChanged=true;
                     Reg->CloseKey();
                 }
+                */
 
                 //Test if MediaInfo shell extension is known
                 if (Player!="" && Reg->OpenKey(Player+_T("\\Shell\\MediaInfo\\Command"), false))
@@ -611,6 +620,7 @@ int Preferences::ExplorerShell()
                     Player="Folder";
 
                 //Test if old Media Info shell extension is known
+                /*
                 if (Reg->OpenKey(Player+_T("\\Shell\\Media Info\\Command"), false))
                 {
                     //Should not be here, deleting
@@ -619,6 +629,7 @@ int Preferences::ExplorerShell()
                     IsChanged=true;
                     Reg->CloseKey();
                 }
+                */
 
                 //Test if MediaInfo shell extension is known
                 if (Reg->OpenKey(Player+_T("\\Shell\\MediaInfo\\Command"), false))
@@ -651,7 +662,7 @@ int Preferences::ExplorerShell()
                     if (ShellExtension)
                     {
                         //Create it
-                        Reg->DeleteKey(Player+"\\Shell\\Media Info"); //Delete the lod version if it exists
+                        //Reg->DeleteKey(Player+"\\Shell\\Media Info"); //Delete the lod version if it exists
                         Reg->OpenKey(Player+_T("\\Shell\\MediaInfo\\Command"), true);
                         AnsiString ShellExtensionToWtrite="\"" + Application->ExeName +"\" \"%1\"";
                         try {Reg->WriteString(_T(""), ShellExtensionToWtrite);} catch (...){}
@@ -809,6 +820,7 @@ int Preferences::ShellToolTip()
         ".dvr-ms;"
         ".eac3;"
         ".evo;"
+        ".f4v;"
         ".flac;"
         ".flv;"
         ".gvi;"
@@ -859,6 +871,7 @@ int Preferences::ShellToolTip()
         ".rmvb;"
         ".smv;"
         ".swf;"
+        ".stl;"
         ".tp;"
         ".trp;"
         ".ts;"
@@ -878,11 +891,11 @@ int Preferences::ShellToolTip()
         if (ShellInfoTip)
         {
             //test if good writing
-            std::string DLL_Name=Application->ExeName.c_str();
+            std::string DLL_Name=Ztring(Application->ExeName.c_str()).To_Local();
             DLL_Name.resize(DLL_Name.rfind('\\')); //Removing ".exe"
             DLL_Name+="\\MediaInfo_InfoTip.dll";
             std::string ShellInfoTipToWtrite="\"" + DLL_Name +"\"";
-            std::string ShellInfoTip_Existing=Reg_User->ReadString(_T("")).c_str();
+            std::string ShellInfoTip_Existing=Ztring(Reg_User->ReadString(_T("")).c_str()).To_Local();
             if (ShellInfoTip_Existing!=ShellInfoTipToWtrite)
             {
                 //This is not the good shell extension, writing new one
@@ -919,7 +932,7 @@ int Preferences::ShellToolTip()
             try {Reg_User->WriteString("", "MediaInfoShellExt_ Class");} catch (...){}
             Reg_User->CloseKey();
             Reg_User->OpenKey("Software\\Classes\\CLSID\\{869C14C8-1830-491F-B575-5F9AB40D2B42}\\InprocServer32", true);
-            std::string DLL_Name=Application->ExeName.c_str();
+            std::string DLL_Name=Ztring(Application->ExeName.c_str()).To_Local();
             DLL_Name.resize(DLL_Name.rfind('\\')); //Removing ".exe"
             DLL_Name+="\\MediaInfo_InfoTip.dll";
             std::string ShellInfoTipToWtrite="\"" + DLL_Name +"\"";
