@@ -1,17 +1,17 @@
 // GUI_Main - Main interface of MediaInfo
-// Copyright (C) 2002-2009 Jerome Martinez, Zen@MediaArea.net
+// Copyright (C) 2002-2010 MediaArea.net SARL, Info@MediaArea.net
 //
-// This program is free software: you can redistribute it and/or modify
-// it under the terms of the GNU General Public License as published by
+// This program is free software: you can redistribute it and/or modify it
+// under the terms of the GNU Lesser General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // any later version.
 //
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
-// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-// GNU General Public License for more details.
+// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+// GNU Lesser General Public License for more details.
 //
-// You should have received a copy of the GNU General Public License
+// You should have received a copy of the GNU Lesser General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -248,7 +248,7 @@ void __fastcall TMainF::FormShow(TObject *Sender)
         if (IsWin9X())
         {
             for (int I1=1; I1<=ParamCount(); I1++)
-                I->Open(Ztring().From_Local(ParamStr(I1).c_str()));
+                I->Open(ParamStr(I1).c_str());
         }
         else
         {
@@ -1038,6 +1038,35 @@ void __fastcall TMainF::M_View_HTMLClick(TObject *Sender)
     ChangePage(Page_HTML);
 }
 
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_XMLClick(TObject *Sender)
+{
+    //Language
+    I->Option_Static(_T("Language"), _T("raw"));
+
+    Prefs->Details[Prefs_Custom].Write(_T("XML"));
+    M_View_Custom->Checked=true;
+    ToolBar_View_Custom->Checked=true;
+    ChangePage(Page_Custom);
+}
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_MPEG7Click(TObject *Sender)
+{
+    Prefs->Details[Prefs_Custom].Write(_T("MPEG-7"));
+    M_View_Custom->Checked=true;
+    ToolBar_View_Custom->Checked=true;
+    ChangePage(Page_Custom);
+}
+
+//---------------------------------------------------------------------------
+void __fastcall TMainF::M_View_PBCoreClick(TObject *Sender)
+{
+    Prefs->Details[Prefs_Custom].Write(_T("PBCore_1.2"));
+    M_View_Custom->Checked=true;
+    ToolBar_View_Custom->Checked=true;
+    ChangePage(Page_Custom);
+}
+
 //---------------------------------------------------------------------------
 void __fastcall TMainF::M_View_CustomClick(TObject *Sender)
 {
@@ -1562,9 +1591,9 @@ void __fastcall TMainF::Donate___Click(TObject *Sender)
     ShellExecute(NULL, NULL, (Ztring(_T("http://mediainfo.sourceforge.net/"))+Prefs->Translate(_T("  Language_ISO639"))+_T("/Donate")).c_str(), NULL, NULL, SW_SHOWNORMAL);
 }
 
+//---------------------------------------------------------------------------
 void __fastcall TMainF::M_NewVersionClick(TObject *Sender)
 {
     ShellExecute(NULL, NULL, (Ztring(_T("http://mediainfo.sourceforge.net/"))+Prefs->Translate(_T("  Language_ISO639"))+_T("?NewVersionRequested=true")).c_str(), NULL, NULL, SW_SHOWNORMAL);
 }
-//---------------------------------------------------------------------------
 
